@@ -441,7 +441,8 @@ gboolean rsslib_cache_write_item(rsslib_cache_init_data *save_data,rsslib_cache_
     }
 
     /* save the on_server flag */
-    cache_write_boolean(cache, item_data->on_server);
+    if (cache_write_boolean(cache, item_data->on_server))
+        return TRUE;
     
     tmp = ftell(cache);
     fseek(cache, pos, SEEK_SET);
